/*
 * This file is part of SubLink.
 * Copyright (C) 2009  Jeferson Hultmann <hultmann@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

var EXPORTED_SYMBOLS = ["buttonCmd", "buttonClick", "buttonTooltip", "buttonImage"];

Components.utils.import("resource://sublink-migreme-modules/util.js");


function buttonClick(evt) {
  if (evt.button !== 1 || evt.detail !== 1) {
    util.log("buttonClick ret");
    return;
  }

  // middle click
  var button = evt.target;
  var win = button.ownerDocument.defaultView;
  util.openPage("http://migre.me/", "tab", win);
}


function buttonCmd(evt) {
  var command = evt.target;

  var win = command.ownerDocument.defaultView;
  var browser = win.getBrowser().selectedBrowser;
  var uri = browser.contentDocument.documentURIObject;

  Components.utils.import("resource://sublink-migreme-modules/redir-storage.js");
  var redir = redirStorage.getSavedRedir(uri);
  if (redir) {
    util.toClipboard(redir);
    return;
  }

  function onSuccess(info) {
    util.toClipboard(info.shortUri.spec);
  }

  util.toClipboard("");
  util.toTinyUrlRequest(uri, browser, onSuccess);
}


function buttonTooltip(tooltip) {
  var win = tooltip.ownerDocument.defaultView;
  var uri = win.getBrowser().selectedBrowser.contentDocument.documentURIObject;
  var text;

  Components.utils.import("resource://sublink-migreme-modules/redir-storage.js");
  var redir = redirStorage.getSavedRedir(uri);
  if (redir) {
    text = util.getText("button.create.saved.tooltip", redir);
  } else {
    text = util.getText("button.create.new.tooltip", "migre.me");
  }
  tooltip.setAttribute("label", text);
}


function buttonImage(button, mode) {
  /*
  util.log("buttonImage " + mode);
  if (util.isOsX) {
    var info = Cc["@mozilla.org/xre/app-info;1"].getService(Ci.nsIXULAppInfo);
    if (info.platformVersion.indexOf("1.9") === 0) { // Gecko 1.9.2
      button.style.MozImageRegion = "rect(0px, 36px, 23px, 0px)";  // temp random rect
      buttonImageOSX(button, mode === "active");
      return;
    }
  }
  */


  switch (mode) {
    case "small":
      //button.style.MozImageRegion = "rect(0px, 16px, 16px, 0px)";
      buttonImageWinLin(button, 16);
      break;
    /*
    case "big":
      button.style.MozImageRegion = "rect(0px, 24px, 24px, 0px)";
      buttonImageWinLin(button, 24);
      break;
    */
  }
}


function buttonImageWinLin(button, size) {
  var doc = button.ownerDocument;

  var cnv = createHtmlElement("canvas", doc);
  cnv.width = size;
  cnv.height = size;
  var ctx = cnv.getContext("2d");


  var favImg = createHtmlElement("img", doc);

  favImg.onload = function(evt) {
    ctx.globalAlpha = 0.8;
    ctx.drawImage(favImg, 0, 0);
    /*
    if (size === 16) {
      ctx.drawImage(favImg, 0, 0);
    } else {
      ctx.drawImage(favImg, 2, 2);
      ctx.globalAlpha = 0.8;
      ctx.drawImage(favImg, 6, 6);
    }
    */
    canvasToButton(cnv, button);
  };


  favImg.onerror = function(evt) {
    var appImg = createHtmlElement("img", doc);
    appImg.onload = function(evt) {
      var imgScale = size/32;
      ctx.scale(imgScale, imgScale);
      ctx.drawImage(appImg, 0, 0);
      canvasToButton(cnv, button);
    }

    setIconSrc(appImg);
  };

  favImg.src = "http://migre.me/migreme.ico";
}

/*
function buttonImageOSX(button, active) {
  var doc = button.ownerDocument;

  var cnv = createHtmlElement("canvas", doc);
  cnv.width = 36;
  cnv.height = 23;
  var ctx = cnv.getContext("2d");


  var bgImg = createHtmlElement("img", doc);

  bgImg.onload = function(evt) {
    ctx.drawImage(bgImg, 0, 0);
    ctx.globalAlpha = active ? 0.6 : 0.9;

    var favImg = createHtmlElement("img", doc);
    favImg.onload = function(evt) {
      ctx.drawImage(favImg, 10, 3);
      canvasToButton(cnv, button);
    };

    favImg.onerror = function(evt) {
      var appImg = createHtmlElement("img", doc);
      appImg.onload = function(evt) {
        ctx.scale(0.5, 0.5);
        ctx.drawImage(appImg, 21, 7);
        canvasToButton(cnv, button);
      }
      setIconSrc(appImg);
    };

    favImg.src = "http://migre.me/migreme.ico";
  };

  // button background
  if (active) {
    bgImg.src = "data:image/png;base64,iVBORw0KGgoAAA...";
  } else {
    bgImg.src = "data:image/png;base64,iVBORw0KGgoAAA...";
  }
}
*/



function setIconSrc(img) {
  /*
  if (Cc["@mozilla.org/extensions/manager;1"]) {
    // 1.9.2
    img.src = "chrome://sublink-migreme/content/icon.png";
  } else {
  */
  var ns = {};
  Components.utils.import("resource://gre/modules/AddonManager.jsm", ns);
  ns.AddonManager.getAddonByID("migre.me@hultmann", function(addon) {
    img.src = addon.iconURL;
  });
  /*
  }
  */
}

function createHtmlElement(tagName, xulDoc) {
  return xulDoc.createElementNS("http://www.w3.org/1999/xhtml", tagName);
}

function canvasToButton(canvas, button) {
  button.style.listStyleImage = "url(" + canvas.toDataURL("image/png") + ")";
  //button.style.MozImageRegion = "auto"; // auto faz o botao ficar imenso por alguns instantes
}
